# Copyright 2005 PyTom <pytom@bishoujo.us>
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

# Common interface things that aren't as convenient as they should be in
# gtk.

import gtk
import os

def messagebox(parent, message, error=True):

    if error:
        type = gtk.MESSAGE_ERROR
    else:
        type = gtk.MESSAGE_INFO

    md = gtk.MessageDialog(parent,
                           flags=gtk.DIALOG_MODAL,
                           type=type,
                           buttons=gtk.BUTTONS_OK,
                           message_format=message)
    md.run()
    md.destroy()

def yesnobox(parent, message):

    md = gtk.MessageDialog(parent,
                           flags=gtk.DIALOG_MODAL,
                           type=gtk.MESSAGE_QUESTION,
                           buttons=gtk.BUTTONS_YES_NO,
                           message_format=message)
    rv = md.run()
    md.destroy()

    return rv == gtk.RESPONSE_YES

def entrybox(parent, title, prompt, default=''):

    d = gtk.Dialog(title,
                   parent,
                   gtk.DIALOG_MODAL,
                   ( gtk.STOCK_OK, gtk.RESPONSE_ACCEPT,
                     gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT ))

    vbox = gtk.VBox()

    l = gtk.Label(prompt)
    vbox.pack_start(l, True)

    e = gtk.Entry()
    e.set_text(default)
    vbox.pack_start(e, True)

    vbox.set_border_width(20)
    vbox.set_spacing(20)

    d.vbox.add(vbox)

    d.show_all()

    if d.run() == gtk.RESPONSE_ACCEPT:
        rv = e.get_text()
    else:
        rv = None

    d.destroy()
    return rv

def dirbox(parent, title, default=None):

    d = gtk.FileChooserDialog(title=title,
                              parent=parent,
                              action=gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
                              buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                                       gtk.STOCK_OK, gtk.RESPONSE_OK))

    if default:
        d.set_filename(default)

    d.set_default_response(gtk.RESPONSE_OK)

    res = d.run()
    
    if res != gtk.RESPONSE_OK:
        rv = None
    else:
        rv = d.get_filename()

    d.destroy()
    return rv

def savebox(parent, title, default=None):

    d = gtk.FileChooserDialog(title=title,
                              parent=parent,
                              action=gtk.FILE_CHOOSER_ACTION_SAVE,
                              buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                                       gtk.STOCK_OK, gtk.RESPONSE_OK))

    if default:
        d.set_current_name(default)

    d.set_default_response(gtk.RESPONSE_OK)

    while True:
        res = d.run()

        if res != gtk.RESPONSE_OK:
            rv = None
            break

        rv = d.get_filename()

        if not os.path.exists(rv):
            break

        if yesnobox(d, "%s already exists. Are you sure you want to overwrite it?" % rv):
            break

    d.destroy()
    return rv

def loadbox(parent, title):

    d = gtk.FileChooserDialog(title=title,
                              parent=parent,
                              action=gtk.FILE_CHOOSER_ACTION_OPEN,
                              buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                                       gtk.STOCK_OK, gtk.RESPONSE_OK))

    d.set_default_response(gtk.RESPONSE_OK)

    res = d.run()

    if res != gtk.RESPONSE_OK:
        rv = None
    else:
        rv = d.get_filename()

    d.destroy()
    return rv

    
def newbox(parent, title, prompt, choices):

    d = gtk.Dialog(title,
                   parent,
                   gtk.DIALOG_MODAL,
                   ( gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
                     

    vbox = gtk.VBox()

    l = gtk.Label(prompt)
    vbox.pack_start(l, True)

    c = gtk.combo_box_new_text()

    for i in choices:
        c.append_text(i)

    c.set_active(0)
    vbox.pack_start(c, True)

    vbox.set_border_width(20)
    vbox.set_spacing(20)

    d.vbox.add(vbox)

    d.show_all()

    if d.run() == gtk.RESPONSE_ACCEPT:
        rv = choices[c.get_active()]
    else:
        rv = None

    d.destroy()
    return rv
